@@ -1,7 +1,7 @@
 from random import randint, choice
 
 
-def checkbox(self):
+def checkbox():
     """
         It is a function with the equivalent values of the present checkboxes in the question.
 
